==> elki_0.6.0.orig.tar.bz2: elki-0.6.0/src/de/lmu/ifi/dbs/elki/data/model/ClusterModel.java <==
package de.lmu.ifi.dbs.elki.data.model;

/*
 This file is part of ELKI:
 Environment for Developing KDD-Applications Supported by Index-Structures

 Copyright (C) 2013
 Ludwig-Maximilians-Universität München
 Lehr- und Forschungseinheit für Datenbanksysteme
 ELKI Development Team

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU Affero General Public License for more details.

 You should have received a copy of the GNU Affero General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Generic cluster model. Does not supply additional meta information except
 * that it is a cluster. Since there is no meta information, you should use the
 * static {@link #CLUSTER} object.
 * 
 * @author Erich Schubert
 * 
 * @apiviz.landmark
 */
public final class ClusterModel extends BaseModel {
  /**
   * Static cluster model that can be shared for all clusters (since the object
   * doesn't include meta information.
   */
  public static final ClusterModel CLUSTER = new ClusterModel();

  @Override
  public String toString() {
    return "ClusterModel";
  }
}

==> elki_0.6.5~20141030.orig.tar.bz2: elki-0.6.5~20141030/src/de/lmu/ifi/dbs/elki/data/model/ClusterModel.java <==
package de.lmu.ifi.dbs.elki.data.model;

/*
 This file is part of ELKI:
 Environment for Developing KDD-Applications Supported by Index-Structures

 Copyright (C) 2014
 Ludwig-Maximilians-Universität München
 Lehr- und Forschungseinheit für Datenbanksysteme
 ELKI Development Team

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU Affero General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU Affero General Public License for more details.

 You should have received a copy of the GNU Affero General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Generic cluster model. Does not supply additional meta information except
 * that it is a cluster. Since there is no meta information, you should use the
 * static {@link #CLUSTER} object.
 * 
 * @author Erich Schubert
 * 
 * @apiviz.landmark
 */
public final class ClusterModel extends AbstractModel {
  /**
   * Static cluster model that can be shared for all clusters (since the object
   * doesn't include meta information.
   */
  public static final ClusterModel CLUSTER = new ClusterModel();

  @Override
  public String toString() {
    return "ClusterModel";
  }
}
